﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.GeneticProgramming.Robocode {
  [StorableClass]
  public class GetY : CodeNode, INumericalMethod {
    public override int MinimumArity { get { return 0; } }
    public override int MaximumArity { get { return 0; } }

    [Storable]
    public override string Prefix { get; set; }

    [Storable]
    public override string Suffix { get; set; }

    [StorableConstructor]
    protected GetY(bool deserializing) : base(deserializing) { }
    protected GetY(GetY original, Cloner cloner) : base(original, cloner) { }

    public GetY()
      : base("GetY", "Returns the Y position of the robot. (0,0) is at the bottom left of the battlefield.") {
      Prefix = "getY(";
      Suffix = ")";
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new GetY(this, cloner);
    }

    public override string Interpret(ISymbolicExpressionTreeNode node, IEnumerable<ISymbolicExpressionTreeNode> children) {
      return Prefix + Suffix;
    }
  }
}